@@ -1,6 +1,7 @@
 export * from './User';
 export * from './UserRecentlyViewedPatient';
 export * from './UserPreference';
+export * from './UserLoginAttempt';
 export * from './LocalSystemFact';
 export * from './PortalUser';
 export * from './Device';
@@ -59,6 +60,7 @@ export * from './LabTestPanelLabTestTypes';
 export * from './ImagingRequest';
 export * from './ImagingRequestArea';
 export * from './ImagingAreaExternalCode';
+export * from './ImagingTypeExternalCode';
 export * from './ImagingResult';
 
 export * from './Program';
@@ -110,14 +112,6 @@ export * from './Permission';
 export * from './Role';
 
 export * from './Invoice';
-export * from './InvoiceProduct';
-export * from './InvoiceDiscount';
-export * from './InvoiceInsurer';
-export * from './InvoiceItem';
-export * from './InvoiceItemDiscount';
-export * from './InvoicePayment';
-export * from './InvoicePatientPayment';
-export * from './InvoiceInsurerPayment';
 
 export * from './ReferenceDrug';
 export * from './MedicationAdministrationRecord';
